@@ -61,8 +61,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "isensor.h"
 #include "idcmi.h"
 
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil dcmi";
+#else
+static char * progver   = "3.08";
 static char * progname  = "idcmi";
-static char * progver   = "3.07";
+#endif
 extern char   fdebug;  /*from ipmicmd.c*/
 static uchar  g_bus  = PUBLIC_BUS;
 static uchar  g_sa   = BMC_SA;
