@@ -113,10 +113,13 @@ extern int get_LastError( void );  /* ipmilan.c */
 extern int GetSDRRepositoryInfo(int *nret, int *fdev);  /*isensor.h*/
 #ifdef METACOMMAND
 extern int ipmi_kontronoem_main(void * intf, int  argc, char ** argv);
+extern char *progver;  /*from ipmiutil.c*/
+static char *progname  = "ipmiutil fru";
+#else
+static char *progver   = "3.11";
+static char *progname  = "ifru";
 #endif
 
-static char *progname  = "ifru";
-static char *progver   = "3.07";
 static int  vend_id = 0; 
 static int  prod_id = 0; 
 static char fdebug = 0;
@@ -197,7 +200,7 @@ static int sdr_get_reservation(uchar *res_id, int fdev) { return(-1); }
 #define STRING_DATA_TYPE_SIX_BIT_ASCII  0x02
 #define STRING_DATA_TYPE_LANG_DEPENDENT 0x03
 
-#define FRUCHUNK_SZ   16
+#define FRUCHUNK_SZ   16   /* optimal chunk = 16 bytes */
 #define FRU_END         0xC1
 #define FRU_EMPTY_FIELD 0xC0
 #define FRU_TYPE_MASK   0xC0
@@ -267,7 +270,7 @@ int
 load_fru(uchar sa, uchar frudev, uchar frutype, uchar **pfrubuf)
 {
    int ret = 0;
-   uchar indata[16];
+   uchar indata[FRUCHUNK_SZ+9];
    uchar resp[18];
    int sresp;
    uchar cc;
@@ -279,6 +282,7 @@ load_fru(uchar sa, uchar frudev, uchar frutype, uchar **pfrubuf)
 
    if (pfrubuf == NULL) return(ERR_BAD_PARAM);
    *pfrubuf = NULL;
+   memset(indata, 0, sizeof(indata));
    indata[0] = frudev;
    sresp = sizeof(resp);
    if (fdebug) printf("load_fru: sa=%02x, frudev=%02x, addrtype=%d\n",
@@ -312,14 +316,14 @@ load_fru(uchar sa, uchar frudev, uchar frutype, uchar **pfrubuf)
 	}
         indata[1] = fruoff & 0x00FF;
         indata[2] = (fruoff & 0xFF00) >> 8;
-	sresp = sizeof(resp);
+        sresp = sizeof(resp);
         ret = ipmi_cmd_mc(READ_FRU_DATA,indata,4,resp,&sresp,&cc,fdebug);
-	if (ret != 0) break;
-	else if (cc != 0) {
-		if (i == 0) ret = cc & 0x00ff; 
-		if (fdebug) printf("read_fru[%d]: ret = %d cc = %x\n",i,ret,cc);
-		break; 
-	}
+        if (ret != 0) break;
+        else if (cc != 0) {
+           if (i == 0) ret = cc & 0x00ff; 
+           if (fdebug) printf("read_fru[%d]: ret = %d cc = %x\n",i,ret,cc);
+           break; 
+        }
         memcpy(&frubuf[i],&resp[1],chunk);
    }
 
@@ -335,16 +339,16 @@ load_fru(uchar sa, uchar frudev, uchar frutype, uchar **pfrubuf)
         if (fdebug) printf("get_SystemGuid: ret = %d\n",rv);
      }
      if (rv == 0 && cc == 0) {
-	if (fdebug) {
-	   printf("system guid (%d): ",sresp);
-	   for (i=0; i<16; i++) printf("%02x ",resp[i]);
-	   printf("\n");
-	}
-	memcpy(&guid,&resp,16);
-   	guid[16] = 0;
+       if (fdebug) {
+	     printf("system guid (%d): ",sresp);
+	     for (i=0; i<16; i++) printf("%02x ",resp[i]);
+	     printf("\n");
+       }
+       memcpy(&guid,&resp,16);
+       guid[16] = 0;
      } else {
-	printf("WARNING: GetSystemGuid error %d, %s\n",rv,decode_rv(rv));
-	/*do not pass this error upstream*/
+       printf("WARNING: GetSystemGuid error %d, %s\n",rv,decode_rv(rv));
+       /*do not pass this error upstream*/
      }
    } /*endif*/
    return(ret);
@@ -843,30 +847,31 @@ show_fru(uchar sa, uchar frudev, uchar frutype, uchar *pfrubuf)
    pfru0 = &pfrubuf[0];  /*pointer to fru start*/
    pfru = &pfrubuf[0];
    sz = 8;  /*minimum for common header*/
-   for (i = 1; i < 6; i++) 	/* walk thru offsets */
-	if (pfrubuf[i] != 0) sz = pfrubuf[i] * 8;
+   for (i = 1; i < 6; i++) {	/* walk thru offsets */
+	 if (pfrubuf[i] != 0) sz = pfrubuf[i] * 8;
+   }
    if (sz > 8) {   		/* if have at least one section */
-	if (pfrubuf[5] != 0) j = 5 + pfrubuf[sz+2]; /*if multi-record area*/
-	else j = pfrubuf[sz+1] * 8;   /* else add length of last section */
-	sz += j;
+	 if (pfrubuf[5] != 0) j = 5 + pfrubuf[sz+2]; /*if multi-record area*/
+	 else j = pfrubuf[sz+1] * 8;   /* else add length of last section */
+	 sz += j;
    }
 
    /* Now, sz = size used, sfru = total available size */
    if (sz > sfru) {
       if (fdebug) {
-	uchar hsum;
+        uchar hsum;
         printf("FRU Header: ");
         for (i = 0; i < 8; i++) printf("%02x ",pfrubuf[i]);
         printf("\n");
         hsum = calc_cksum(&pfrubuf[0],7);
-	if (pfrubuf[7] != hsum)
+        if (pfrubuf[7] != hsum)
            printf("FRU Header checksum mismatch (%x != %x)\n",pfrubuf[7],hsum);
       }
       printf("FRU size used=%d > available=%d\n",sz,sfru);
       if (fpicmg || fdoanyway) sz = sfru;  /*do it anyway*/
       else {
         printf("Please apply the correct FRU/SDR diskette\n");
-	return(ERR_OTHER);
+        return(ERR_OTHER);
       }
    }
    /* internal area offset, length */
@@ -886,10 +891,11 @@ show_fru(uchar sa, uchar frudev, uchar frutype, uchar *pfrubuf)
    mlen = 0;
    if (moff > 0) {
       for (i = moff; i < sfru; ) {
+         if (pfrubuf[i] == 0 && pfrubuf[i+2] == 0) break; /*type/len invalid*/
          j = 5 + pfrubuf[i+2];
-	 mlen += j;
+         mlen += j;
          if (pfrubuf[i+1] & 0x80) break;
-	 i += j;
+         i += j;
       }
    }
 
@@ -1053,8 +1059,9 @@ show_fru(uchar sa, uchar frudev, uchar frutype, uchar *pfrubuf)
       j = moff;
       for (i = 0; j < sz ; i++)
       {
+         if (pfru[0] == 0 && pfru[2] == 0) break; /*type/len invalid*/ 
          n = pfru[2];  /* len of this record */
-	 show_fru_multi(devstr,i,pfru[0],&pfru[5],n);
+         show_fru_multi(devstr,i,pfru[0],&pfru[5],n);
          j += (5 + n);
          if (pfru[1] & 0x80) j = sz;  /*0x80 = last in list, break*/
          pfru += (5 + n);
@@ -1074,8 +1081,8 @@ int write_fru_data(uchar id, ushort offset, uchar *data, int dlen, char fdebug)
    int ret = -1;
    int chunk;
    ushort fruoff;
-   uchar req[25];
-   uchar resp[16];
+   uchar req[FRUCHUNK_SZ+9];
+   uchar resp[FRUCHUNK_SZ];
    int sresp;
    uchar cc;
    int i, j;
@@ -1643,7 +1650,7 @@ int i_fru(int argc, char **argv)
    char do_reserve = 1;
    char devstr[32];
 
-   printf("%s: version %s\n",progname,progver);
+   printf("%s version %s\n",progname,progver);
           
    parse_lan_options('V',"4",0);  /*default to admin privilege*/
    while ( (c = getopt( argc, argv,"a:bcd:efhkl:m:n:i:p:r:s:t:v:xyzT:V:J:EYF:P:N:R:U:Z:?")) != EOF )
@@ -1766,7 +1773,7 @@ int i_fru(int argc, char **argv)
                 parse_lan_options(c,optarg,fdebug);
                 break;
           default:
-                printf("Usage: %s [-bceikmtvx -a asset_tag -s ser_num -NUPREFTVY]\n",
+                printf("Usage: %s [-bceikmtvx -a asset_tag -s ser_num -NUPREFTVYZ]\n",
 			 progname);
 		printf("   -a tag   Sets the Product Asset Tag\n");
 		printf("   -b       Only show Baseboard FRU data\n");
@@ -1877,25 +1884,26 @@ int i_fru(int argc, char **argv)
        recid = 0;
        while (recid != LAST_REC)
        {
-	  if (do_reserve) {
+         if (do_reserve) {
              /* reserve the SDR repository */
              ret = sdr_get_reservation((uchar *)&rsvid,fdevsdrs);
              if (fdebug) printf("sdr_get_reservation ret=%d\n",ret);
-	     if (ret == 0) do_reserve = 0;
-	  }
+             if (ret == 0) do_reserve = 0;
+         }
 
-	  len = sizeof(sdr); /*sizeof(sdr); get 32 sdr bytes*/
-	  ret = get_sdr(recid,rsvid,&nextid,sdr,&len,&cc);
-	  if ((ret != 0) || (cc != 0)) {
-	    printf("SDR[%04x] error %d ccode = %x\n",recid,ret,cc);
-	    if ((cc == 0xC5) || (cc == 0x83)) ; /*do not stop (ARC)*/
-	    else break;  /*stop if errors*/
-	  }
-          if (len >= MIN_SDR_SZ) {
-	     if ((sdr[3] == 0x11) || (sdr[3] == 0x12)) /*SDR FRU or IPMB type*/
-	        ret = get_show_fru(recid, sdr,len);
-	     do_reserve = 1;
-          }  /*endif get_show_fru */
+         len = sizeof(sdr); /*sizeof(sdr); get 32 sdr bytes*/
+         ret = get_sdr(recid,rsvid,&nextid,sdr,&len,&cc);
+         if ((ret != 0) || (cc != 0)) {
+             printf("SDR[%04x] error %d ccode = %x\n",recid,ret,cc);
+             if (cc == 0xC5) do_reserve = 1; /*retry w reserve*/
+             if (cc == 0x83) os_usleep(0,100); /*busy, retry*/
+             else break;  /*stop if errors*/
+         }
+         if (len >= MIN_SDR_SZ) {
+	        if ((sdr[3] == 0x11) || (sdr[3] == 0x12)) /*SDR FRU or IPMB type*/
+	           ret = get_show_fru(recid, sdr,len);
+	        do_reserve = 1;
+         }  /*endif get_show_fru */
 #ifdef PICMG_CHILD
            /*
             * Special logic for blade child MCs in PICMG ATCA systems 
@@ -2025,7 +2033,11 @@ int i_fru(int argc, char **argv)
 
    if (fdump && ret == 0) {
       /* Dump FRU to a binary file */
+#ifdef WIN32
+      fp = fopen(binfile,"wb");
+#else
       fp = fopen(binfile,"w");
+#endif
       if (fp == NULL) {
          ret = get_LastError();
          printf("Cannot open file %s, error %d\n",binfile,ret);
@@ -2043,9 +2055,13 @@ int i_fru(int argc, char **argv)
    else if (frestore) {
       uchar cksum;
       /* Restore FRU from a binary file */
+#ifdef WIN32
+      fp = fopen(binfile,"rb");
+#else
       fp = fopen(binfile,"r");
+#endif
       if (fp == NULL) {
-	 ret = get_LastError();
+         ret = get_LastError();
          printf("Cannot open file %s, error %d\n",binfile,ret);
       } else {
 	 ret = 0;
@@ -2072,10 +2088,10 @@ int i_fru(int argc, char **argv)
             free_fru(frubuf);
 	 }
 	 if (ret == 0) {  /*successfully read data*/
-            printf("Writing FRU size %d from %s  ...\n",sfru,binfile);
-	    ret = write_fru_data(g_fruid, 0, frubuf, sfru, fdebug);
-            free_fru(frubuf);
-            if (ret != 0) printf("write_fru error %d (0x%02x)\n",ret,ret);
+        printf("Writing FRU size %d from %s  ...\n",sfru,binfile);
+        ret = write_fru_data(g_fruid, 0, frubuf, sfru, fdebug);
+        free_fru(frubuf);
+        if (ret != 0) printf("write_fru error %d (0x%02x)\n",ret,ret);
 	    else {  /* successful, show new data */
                ret = load_fru(sa,g_fruid,g_frutype,&pfru);
 	       if (ret != 0) show_loadfru_error(sa,g_fruid,ret);
