@@ -168,8 +168,13 @@ extern void free_sdr_cache(uchar *pret); /*see isensor.c*/
 /*
  * Global variables 
  */
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil getevent";
+#else
+static char * progver   = "3.08";
 static char * progname  = "igetevent";
-static char * progver   = "3.07";
+#endif
 static char   fdebug    = 0;
 static char   fipmilan  = 0;
 static char   frunonce  = 0;
