@@ -108,8 +108,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil reset";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ireset";
+#endif
 static uchar  ipmi_maj;
 static uchar  ipmi_min;
 static uchar  sms_sa = 0x81;
@@ -205,7 +210,7 @@ char *reset_str(uchar breset, uchar bopt)
         case 4:  str = "sending NMI"; break;
         case 5:  str = "shutdown/reset"; break;  
         case 6:  str = "shutdown/power_off"; break; /*via agent*/
-        case 7:  str = "cold reset"; break; 
+        case 7:  str = "cold reset BMC"; break; 
         default: str = "resetting"; break;
    }
    if (bopt > 0) 
@@ -546,7 +551,7 @@ main(int argc, char **argv)
 		    iana[1] = ((mfg & 0x00FF00) >> 8);
 		    iana[2] = (mfg & 0x0000FF);
 		    break;
-          case 'k': breset = 7;    break;  /* cold reset */
+          case 'k': breset = 7;    break;  /* cold reset to BMC */
           case 'w': fwait = 1;     break;  /* wait for ready */
           case 'y': fpersist = 1;  break;  /* yes, persist boot options */
           case 'm': /* specific MC, 3-byte address, e.g. "409600" */
@@ -672,7 +677,7 @@ main(int argc, char **argv)
        }
    }
 
-   if (breset == 7) { /*do Cold Reset */
+   if (breset == 7) { /*do Cold Reset to BMC */
       printf("%s: %s ...\n",progname,reset_str(breset,bopt));
       rslen = sizeof(rsdata);
       ret = ipmi_cmdraw( 0x02, NETFN_APP, g_sa, g_bus, g_lun,
@@ -681,9 +686,9 @@ main(int argc, char **argv)
          printf("cold_reset(%02x) ret=%d cc=%x, rslen=%d\n",g_sa,ret,cc,rslen);
       if (ret == 0) ret = cc;
       if (ret == 0) 
-  	 printf("%s: Cold_Reset ok\n",progname);
+  	 printf("%s: Cold_Reset to BMC ok\n",progname);
       else
-  	 printf("%s: Cold_Reset error %d\n",progname,ret);
+  	 printf("%s: Cold_Reset to BMC error %d\n",progname,ret);
       ipmi_close_(); 
 
    } else if (fshutdown && fipmilan && (platform == platIntel)) { /*soft reset*/
