@@ -97,8 +97,13 @@ int   gettimeofday(struct timeval *tv, struct timezone *tz);
 
 extern int verbose;
 extern char   fdebug;  /*from ipmicmd.c*/
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil tsol";
+#else
+static char * progver   = "3.08";
 static char * progname  = "itsol";
-static char * progver   = "3.07";
+#endif
 static uchar  g_bus  = PUBLIC_BUS;
 static uchar  g_sa   = BMC_SA;
 static uchar  g_lun  = BMC_LUN;
