@@ -83,8 +83,13 @@ extern char  fdebug;   /*ipmicmd.c*/
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil inteloem";
+#else
+static char * progver   = "3.08";
 static char * progname  = "iinteloem";
+#endif
 static char  fRelayBits = 0;
 static uchar g_bus = PUBLIC_BUS;
 static uchar g_sa  = BMC_SA;
@@ -1081,7 +1086,7 @@ int decode_mem_intel(int prod, uchar b2, uchar b3, char *desc, int *psz)
    if (! is_remote()) {
       fsm_debug = fdebug;
       rv = get_MemDesc(array,dimm,desc,psz);
-      /* if (rv != 0) desc has "DIMM[%d}" */ 
+      /* if (rv != 0) desc has "DIMM(%d)" */ 
    } 
    if (rv != 0) {  
       /* either remote, or get_MemDesc failed, use common product defaults*/
@@ -1107,7 +1112,8 @@ int decode_mem_intel(int prod, uchar b2, uchar b3, char *desc, int *psz)
         n = strlen_(pstr);
         strncpy(desc, pstr, n+1);
       } else {
-	n = sprintf(desc,"DIMM[%d]",dimm);
+        if (bdata == 0xFF) n = sprintf(desc,DIMM_UNKNOWN);  /* invalid */
+        else n = sprintf(desc,DIMM_NUM,dimm);
       } 
       *psz = n;
    }
