@@ -45,8 +45,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 extern int decode_sensor_intel_nm(uchar *sdr,uchar *reading,
 				  char *pstring,int slen);  /*oem_intel.c*/
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil quantaoem";
+#else
+static char * progver   = "3.08";
 static char * progname  = "iquantaoem";
+#endif
 static char fdbg = 0;
 
 /*
