@@ -108,8 +108,13 @@ static const struct valstr sunoem_led_mode_optvals[] = {
 };
 
 /* global variables */
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil sunoem";
+#else
+static char * progver   = "3.08";
 static char * progname  = "isunoem";
-static char * progver   = "3.07";
+#endif
 static char   fdebug    = 0;
 static uchar  g_bus  = PUBLIC_BUS;
 static uchar  g_sa   = BMC_SA;
